@@ -1,5 +1,7 @@
 from __future__ import annotations as _annotations
 
+from collections.abc import Iterator
+from importlib.metadata import version
 from pathlib import Path
 
 import pytest
@@ -7,11 +9,12 @@ import pytest
 from .eval_example import EvalExample
 from .find_examples import CodeExample, find_examples
 
-__version__ = '0.0.13'
+__version__ = version('pytest_examples')
 __all__ = 'find_examples', 'CodeExample', 'EvalExample'
 
 
-def pytest_addoption(parser):
+def pytest_addoption(parser) -> None:
+    """Add options to the pytest command line."""
     group = parser.getgroup('examples')
     group.addoption(
         '--update-examples',
@@ -32,10 +35,8 @@ summary: str | None = None
 
 
 @pytest.fixture(scope='session')
-def _examples_to_update(pytestconfig: pytest.Config) -> list[CodeExample]:
-    """
-    Don't use this directly, it's just  used by
-    """
+def _examples_to_update(pytestconfig: pytest.Config) -> Iterator[list[CodeExample]]:
+    """Don't use this directly, it's just  used by."""
     global summary
 
     examples_to_update: list[CodeExample] = []
@@ -49,10 +50,8 @@ def _examples_to_update(pytestconfig: pytest.Config) -> list[CodeExample]:
 
 
 @pytest.fixture(name='eval_example')
-def eval_example(tmp_path: Path, request: pytest.FixtureRequest, _examples_to_update) -> EvalExample:
-    """
-    Fixture to return a `EvalExample` instance for running and linting examples.
-    """
+def eval_example(tmp_path: Path, request: pytest.FixtureRequest, _examples_to_update) -> Iterator[EvalExample]:
+    """Fixture to return a `EvalExample` instance for running and linting examples."""
     eval_ex = EvalExample(tmp_path=tmp_path, pytest_request=request)
     yield eval_ex
     if request.config.getoption('update_examples'):
@@ -60,5 +59,6 @@ def eval_example(tmp_path: Path, request: pytest.FixtureRequest, _examples_to_up
 
 
 def pytest_terminal_summary() -> None:
+    """Customise pytest to print the summary of updated examples at the end of the test run."""
     if summary:
         print(summary)
